1. Install Anaconda

2. run "conda create -n seisloc python=3.7"

3. run "conda activate seisloc"

4. run "pip install seisloc"

This is a tool package for data processing purposed for earthquake location. Developed by Jinping ZI(zijinping@hotmail.com) from CUHK Seismology Lab.

